<?php
/**
 * 2007-2017 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * No redistribute in other sites, or copy.
 *
 * @author    smokestorm <demo@demo.com>
 * @copyright 2007-2017 smokestorm
 * added
 * @license   http://localhost
 */

require_once('../../config/config.inc.php');
require_once(dirname(__FILE__).'/../../init.php');
include_once(dirname(__FILE__).'/class/dopplerpopupClass.php');
require_once(dirname(__FILE__).'/class/client.php');
require_once(dirname(__FILE__).'/class/clientresource.php');
require_once(dirname(__FILE__).'/class/suscribe.php');

class DopplerPopup extends Module
{
    public $GUEST_NOT_REGISTERED = 0;
    public $CUSTOMER_REGISTERED = 1;
    public $CUSTOMER_NOT_REGISTERED = 0;
    public $GUEST_REGISTERED = 1;

    public function __construct()
    {
        if (empty($_REQUEST['email']) || !Validate::isEmail($_REQUEST['email'])) {
            echo json_encode(array("message" => $this->error = $this->l('Invalid email address.'), "code" => 0));
        } /* Subscription */
        else {
            if ($_REQUEST['action'] == '0') {
                $register_status = $this->isNewsletterRegistered($_REQUEST['email']);
                if ($register_status > 0) {
                    echo json_encode(
                        array(
                            "message" => $this->error = $this->l('This email address is already registered.'),
                            "code" => 0
                        )
                    );
                }

                $email = pSQL($_REQUEST['email']);
                if (!$this->isRegistered($register_status)) {
                    if (Configuration::get('NW_VERIFICATION_EMAIL')) {
                        // create an unactive entry in the newsletter database
                        if ($register_status == $this->GUEST_NOT_REGISTERED) {
                            $this->registerGuest(
                                $email,
                                false
                            );
                        }

                        if (!$token = $this->getToken(
                            $email,
                            $register_status
                        )
                        ) {
                            return json_encode(
                                array(
                                    "message" => $this->error = $this->l(
                                        'An error occurred during the subscription process.'
                                    ),
                                    "code" => 0
                                )
                            );
                        }

                        $this->sendVerificationEmail(
                            $email,
                            $token
                        );

                        echo json_encode(
                            array(
                                "message" => $this->error = $this->l(
                                    'A verification email has been sent. Please check your inbox.'
                                ),
                                "code" => 0
                            )
                        );
                    } else {
                        if ($this->register(
                            $email,
                            $register_status
                        )
                        ) {
                            $this->sendConfirmationEmail($email);
                            echo json_encode(
                                array(
                                    "message" => $this->error = $this->l('Your email was registered. Thank You!'),
                                    "code" => 1
                                )
                            );
                            die();
                        } else {
                            echo $this->error = $this->l('An error occurred during the subscription process.');
                            die();
                        }
                    }
                }
            }
        }
    }

    protected function sendConfirmationEmail($email)
    {
        //return Mail::Send($this->context->language->id, 'newsletter_conf', 'Newsletter confirmation', null, pSQL($email), null, null, null, null, null, dirname(__FILE__).'/mails/', false, $this->context->shop->id);
    }

    protected function isNewsletterRegistered($customer_email)
    {
        $sql = 'SELECT `email`
				FROM '._DB_PREFIX_.'newsletter
				WHERE `email` = \''.pSQL($customer_email).'\'
				AND id_shop = '.Context::getContext()->shop->id;


        if (Db::getInstance()
              ->getRow($sql)
        ) {
            return $this->GUEST_REGISTERED;
        }

        $sql = 'SELECT `newsletter`
				FROM '._DB_PREFIX_.'customer
				WHERE `email` = \''.pSQL($customer_email).'\'
				AND id_shop = '.Context::getContext()->shop->id;

        if (!$registered = Db::getInstance()
                             ->getRow($sql)
        ) {
            return $this->GUEST_NOT_REGISTERED;
        }

        if ($registered['newsletter'] == '1') {
            return $this->CUSTOMER_REGISTERED;
        }

        return $this->CUSTOMER_NOT_REGISTERED;
    }

    protected function isRegistered($register_status)
    {
        return in_array(
            $register_status,
            array($this->GUEST_REGISTERED, $this->CUSTOMER_REGISTERED)
        );
    }

    protected function register(
        $email,
        $register_status
    ) {
        if ($register_status == $this->GUEST_NOT_REGISTERED) {
            return $this->registerGuest($email);
        }

        if ($register_status == $this->CUSTOMER_NOT_REGISTERED) {
            return $this->registerUser($email);
        }

        return false;
    }

    protected function registerUser($email)
    {
        $sql = 'UPDATE '._DB_PREFIX_.'customer
				SET `newsletter` = 1, newsletter_date_add = NOW(), `ip_registration_newsletter` = \''.pSQL(Tools::getRemoteAddr()).'\'
				WHERE `email` = \''.pSQL($email).'\'
				AND id_shop = '.Context::getContext()->shop->id;
        $dplClient = new DopplerClient(Configuration::get('DOPPLER_API'));
        //$result = $dplClient->user->testApiConnection();
        $result = $dplClient->subscriber->addSubscriber(
            array(
                'SubscribersListID' => Configuration::get('DOPPLER_PROFILE'),
                'EMail' => $email,
                'FirstName' => '',
                'LastName' => ''
            )
        );
        $testConnection = $result->{'Subscriber.AddResult'};
        return Db::getInstance()
                 ->execute($sql);
    }

    protected function sendVerificationEmail(
        $email,
        $token
    ) {
        $verif_url = Context::getContext()->link->getModuleLink(
            'blocknewsletter',
            'verification',
            array(
                'token' => $token,
            )
        );

        return Mail::Send(
            $this->context->language->id,
            'newsletter_verif',
            Mail::l(
                'Email verification',
                $this->context->language->id
            ),
            array('{verif_url}' => $verif_url),
            $email,
            null,
            null,
            null,
            null,
            null,
            dirname(__FILE__).'/mails/',
            false,
            $this->context->shop->id
        );
    }

    protected function registerGuest(
        $email,
        $active = true
    ) {
        $sql = 'INSERT INTO '._DB_PREFIX_.'newsletter (id_shop, id_shop_group, email, newsletter_date_add, ip_registration_newsletter, http_referer, active)
				VALUES
				('.Context::getContext()->shop->id.',
				'.Context::getContext()->shop->id_shop_group.',
				\''.pSQL($email).'\',
				NOW(),
				\''.pSQL(Tools::getRemoteAddr()).'\',
				(
					SELECT c.http_referer
					FROM '._DB_PREFIX_.'connections c
					WHERE c.id_guest = '.(int)Context::getContext()->customer->id.'
					ORDER BY c.date_add DESC LIMIT 1
				),
				'.(int)$active.'
				)';
        $dplClient = new DopplerClient(Configuration::get('DOPPLER_API'));
        //$result = $dplClient->user->testApiConnection();
        $result = $dplClient->subscriber->addSubscriber(
            array(
                'SubscribersListID' => Configuration::get('DOPPLER_PROFILE'),
                'EMail' => $email,
                'FirstName' => '',
                'LastName' => ''
            )
        );
        $testConnection = $result->{'Subscriber.AddResult'};
        return Db::getInstance()
                 ->execute($sql);
    }
}

$dopplerpopupValidator = new DopplerPopup();
